/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import ar.amgomez.idea.remotetail.events.MultipleConsolesListener;
import com.intellij.openapi.project.Project;
import org.picocontainer.Disposable;

/**
 * Represents a set of log consoles.
 * @author Alejandro Gomez
 */
public interface MultipleConsolesModel extends Disposable {

    /**
     * Returns the project associated.
     * @return the project associated.
     */
    Project getProject();

    /**
     * Returns the selected log console.
     * @return the selected log console.
     */
    LogConsoleModel getSelectedLogConsole();

    /**
     * Selects a log console.
     * @param _index the index of the log console to select.
     */
    void setSelectedLogConsole(int _index);

    /**
     * Adds a new log console.
     * @param _logConsoleModel the log console to add.
     */
    void addLogConsole(LogConsoleModel _logConsoleModel);

    /**
     * Removes the currently selected log console.
     */
    void removeLogConsole();

    /**
     * Removes all the log consoles.
     */
    void removeAllConsoles();

    /**
     * Registers a new <code>MultipleConsolesListener<code>.
     * @param _listener the <code>MultipleConsolesListener<code> to register.
     */
    void addMultipleConsolesListener(MultipleConsolesListener _listener);

    /**
     * Unregisters a <code>MultipleConsolesListener<code>.
     * @param _listener the <code>MultipleConsolesListener<code> to unregister.
     */
    void removeMultipleConsolesListener(MultipleConsolesListener _listener);
}
