/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import com.intellij.CommonBundle;
import com.intellij.openapi.util.IconLoader;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.PropertyKey;

import javax.swing.Icon;
import java.net.URL;
import java.util.ResourceBundle;

/**
 * Provides i18ned texts, icons and resources.
 * @author Alejandro Gomez
 */
public class RemoteTailBundle {
    /**
     * The base name for the resource bundle.
     */
    @NonNls
    private static final String BUNDLE_BASE_NAME = "ar.amgomez.idea.remotetail.Resources";
    /**
     * The resource bundle.
     */
    private static final ResourceBundle BUNDLE = ResourceBundle.getBundle(BUNDLE_BASE_NAME);

    /**
     * Private constructor to avoid instantiation.
     */
    private RemoteTailBundle() {
    }

    /**
     * Returns an i18ned message.
     * @param _key the key for requested message.
     * @param _params the optional parameters for message.
     * @return an i18ned message associated with the given key.
     */
    public static String message(@PropertyKey(resourceBundle = BUNDLE_BASE_NAME) final String _key, final Object... _params) {
        return CommonBundle.message(BUNDLE, _key, _params);
    }

    /**
     * Returns an i18ned icon.
     * @param _key the key for requested icon.
     * @return an i18ned icon associated with the given key.
     */
    public static Icon icon(@PropertyKey(resourceBundle = BUNDLE_BASE_NAME) final String _key) {
        return IconLoader.getIcon(message(_key));
    }

    /**
     * Returns an i18ned resource.
     * @param _key the key for requested resource.
     * @return an i18ned resource associated with the given key.
     */
    public static URL resource(@PropertyKey(resourceBundle = BUNDLE_BASE_NAME) final String _key) {
        return RemoteTailBundle.class.getResource(message(_key));
    }
}
