/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import ar.amgomez.idea.remotetail.settings.Settings;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.project.Project;

/**
 * Utility class.
 * @author Alejandro Gomez
 */
public class RemoteTailHelper {

    /**
     * Returns the project from the context.
     * @param _event the context information.
     * @return the project from the context.
     */
    public static Project getProject(final AnActionEvent _event) {
        return (Project)_event.getDataContext().getData(DataConstants.PROJECT);
    }

    /**
     * Returns the plugin configuration.
     * @return the plugin configuration.
     */
    public static Settings getSettings() {
        return getRemoteTailSettings().getSettings();
    }

    /**
     * Returns the <code>RemoteTailSettings</code> component.
     * @return the <code>RemoteTailSettings</code> component.
     */
    public static RemoteTailSettings getRemoteTailSettings() {
        return ApplicationManager.getApplication().getComponent(RemoteTailSettings.class);
    }
}
