/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import com.intellij.openapi.components.ProjectComponent;
import org.jetbrains.annotations.NonNls;

import javax.swing.Icon;

/**
 * The plugin interface.
 * @author Alejandro Gomez
 */
public interface RemoteTailPlugin extends ProjectComponent {

    /**
     * The component name.
     */
    @NonNls
    String COMPONENT_NAME = "RemoteTailPlugin";
    /**
     * The tool window id.
     */
    @NonNls
    String TOOL_WINDOW_ID = "Remote Tail";
    /**
     * The id for the settings action.
     */
    @NonNls
    String REMOTE_TAIL_SETTINGS_ACTION_KEY = "RemoteTail.settings";
    /**
     * The id for the help action.
     */
    @NonNls
    String REMOTE_TAIL_HELP_ACTION_KEY = "RemoteTail.help";
    /**
     * The id for the about action.
     */
    @NonNls
    String REMOTE_TAIL_ABOUT_ACTION_KEY = "RemoteTail.about";
    /**
     * The toolbar name.
     */
    @NonNls
    String REMOTE_TAIL_TOOLBAR_NAME = "RemoteTail.toolbar";
    /**
     * The icon for the tool window.
     */
    Icon ICON = RemoteTailBundle.icon("remotetail.icon");

    /**
     * Returns a component implementation.
     * @param _interfaceClass the interface of the required component.
     * @return the component implementation.
     */
    <T> T getComponent(Class<T> _interfaceClass);
}
