/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import ar.amgomez.idea.remotetail.settings.Settings;
import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.util.JDOMExternalizable;
import org.jetbrains.annotations.NonNls;

import javax.swing.Icon;

/**
 * The interface of the application component responsible for storing the configuration.
 * @author Alejandro Gomez
 */
public interface RemoteTailSettings extends ApplicationComponent, Configurable, JDOMExternalizable {

    /**
     * The user-visible name of the settings component.
     */
    @NonNls
    String COMPONENT_NAME = "RemoteTailSettings";
    /**
     * The name displayed in the settings panel.
     */
    @NonNls
    String DISPLAY_NAME = RemoteTailBundle.message("remotetail.settings.displayName");
    /**
     * The icon representing the settings component.
     */
    Icon ICON = RemoteTailBundle.icon("remotetail.settings.icon");
    /**
     * The topic in the help file which is shown when help for the configurable is requested.
     */
    @NonNls
    String HELP_TOPIC = "remotetail.settings";

    /**
     * Returns this component configuration.
     * @return the configuration values.
     */
    Settings getSettings();

}
