/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.actions;

import ar.amgomez.idea.remotetail.LogConsoleModel;
import ar.amgomez.idea.remotetail.RemoteTailBundle;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.ToggleAction;

/**
 * A toggle action to activate/deactivate sound alarms.
 * @author Alejandro Gomez
 */
public class ErrorAlarmAction extends ToggleAction {

    /**
     * The log console model.
     */
    private LogConsoleModel logConsoleModel;

    /**
     * Creates a new instance.
     * @param _logConsoleModel the log console model associated whith this action.
     */
    public ErrorAlarmAction(final LogConsoleModel _logConsoleModel) {
        super(RemoteTailBundle.message("remotetail.alarm.text"), RemoteTailBundle.message("remotetail.alarm.description"), RemoteTailBundle.icon("remotetail.alarm.icon"));
        logConsoleModel = _logConsoleModel;
    }

    /**
     * Returns the selection state of this action.
     * @param _event information about the invocation context.
     * @return the state of this action.
     */
    @Override
    public boolean isSelected(final AnActionEvent _event) {
        return logConsoleModel.isPlaySoundOnAlarm();
    }

    /**
     * Sets the selection state for this action.
     * Notifies the model about the change.
     * @param _event information about the invocation context.
     * @param _state the new selection state.
     */
    @Override
    public void setSelected(final AnActionEvent _event, final boolean _state) {
        logConsoleModel.setPlaySoundOnAlarm(_state);
    }
}
