/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.actions;

import ar.amgomez.idea.remotetail.LogConsoleModel;
import ar.amgomez.idea.remotetail.logging.LogLevel;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.ToggleAction;

import javax.swing.Icon;

/**
 * Represents the controller for adding/removing log level filters to/from the model.
 * @author Alejandro Gomez
 */
public abstract class FilterAction extends ToggleAction {

    /**
     * The log console model.
     */
    private LogConsoleModel logConsoleModel;
    /**
     * The selection state for this action.
     */
    private boolean state;

    /**
     * Creates a new instace with the specified text, description and icon.
     * @param _logConsoleModel the log console model associated whith this action.
     * @param _text the text to show.
     * @param _description the text that describes this action.
     * @param _icon the icon
     * @see ToggleAction#ToggleAction(String,String,Icon)
     */
    protected FilterAction(final LogConsoleModel _logConsoleModel, final String _text, final String _description, final Icon _icon) {
        super(_text, _description, _icon);
        logConsoleModel = _logConsoleModel;
    }

    /**
     * Returns the selection state for this action.
     * @param _event the context information.
     * @return the selection state for this action.
     * @see ToggleAction#isSelected(AnActionEvent)
     */
    @Override
    public boolean isSelected(final AnActionEvent _event) {
        return state;
    }

    /**
     * Sets the selection state for this action.
     * If the new state is selected adds the log level represented by action to the model's active filters.
     * If the new state is deselected removes it.
     * @param _event the context information.
     * @param _state the new selection state.
     */
    @Override
    public void setSelected(final AnActionEvent _event, final boolean _state) {
        state = _state;
        if (state) {
            logConsoleModel.addFilter(getFilterLevel());
        } else {
            logConsoleModel.removeFilter(getFilterLevel());
        }
    }

    /**
     * Returns the log level represented by this action.
     * @return LogLevel
     */
    protected abstract LogLevel getFilterLevel();
}
