/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.actions;

import ar.amgomez.idea.remotetail.LogConsoleModel;
import ar.amgomez.idea.remotetail.RemoteTailBundle;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;

/**
 * A toggle action to activate/deactivate popup alarms.
 * @author Alejandro Gomez
 */
public class PrintAction extends AnAction {

    /**
     * The log console model.
     */
    private LogConsoleModel logConsoleModel;

    /**
     * Creates a new instance.
     * @param _logConsoleModel the log console model associated whith this action.
     */
    public PrintAction(final LogConsoleModel _logConsoleModel) {
        super(RemoteTailBundle.message("remotetail.printLog.text"), RemoteTailBundle.message("remotetail.printLog.description"), RemoteTailBundle.icon("remotetail.printLog.icon"));
        logConsoleModel = _logConsoleModel;
    }

    /**
     * Prints the console content.
     * @param _event information about the invocation context.
     */
    @Override
    public void actionPerformed(final AnActionEvent _event) {
        logConsoleModel.print();
    }
}
