/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.events;

import ar.amgomez.idea.remotetail.LogConsoleModel;

import java.util.EventListener;

/**
 * Interface that gets notifications from log consoles.
 * @author Alejandro Gomez
 */
public interface MultipleConsolesListener extends EventListener {

    /**
     * Method called when a new console is added.
     * @param _logConsoleModel the log added console.
     */
    void consoleAdded(LogConsoleModel _logConsoleModel);

    /**
     * Method called when a console is removed.
     * @param _index the index of the removed log console.
     */
    void consoleRemoved(int _index);

    /**
     * Method called when a console is selected.
     * @param _index the index of the selected log console.
     */
    void consoleSelected(int _index);

    /**
     * Method called when a console requests to popup.
     */
    void popup();

    /**
     * Method called when a console requests to play the alarm sound.
     */
    void playSound();
}
