/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import java.io.Serializable;

/**
 * Represents a log entry.
 * @author Alejandro Gomez
 */
public interface LogEntry extends Serializable {

    /**
     * Returns the text of this log entry.
     * @return the text of this log entry.
     */
    String getText();

    /**
     * Returns the category of this category.
     * @return the category of this category.
     */
    LogCategory getCategory();

    /**
     * Checks if this log entry is the header of a sequence of log entries.
     * The line matching the category's pattern is considered to be a header.
     * The subsequent lines (i.e. a stack trace for an exception) is not a header.
     * @return true if this log entry is the header of a sequence of log entries.
     */
    boolean isHeader();

    /**
     * Checks if this log entry is a header of the specified level.
     * @param _level the level.
     * @return true if this log entry is a header of the specified level.
     */
    boolean isHeader(LogLevel _level);

    /**
     * Checks if this log entry is a header of the specified level or a greter level.
     * @param _level the level.
     * @return true if this log entry is a header of the specified level or a greter level.
     */
    boolean isHeaderNonStrict(LogLevel _level);
}
