/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.net.Client;
import org.jetbrains.annotations.NotNull;

/**
 * A factory to create instance of <code>LogEntryProvider</code>.
 * @author Alejandro Gomez
 */
public class LogEntryProviderFactory {

    /**
     * The singleton instance of this factory.
     */
    private static final LogEntryProviderFactory INSTANCE = new LogEntryProviderFactory();

    /**
     * Private constructor to prevent other instances.
     */
    private LogEntryProviderFactory() {
    }

    /**
     * Returns a new instance of <code>LogEntryProvider</code>.
     * @param _client the network protocol client.
     * @return LogEntryProvider the new <code>LogEntryProvider</code> instance.
     */
    @NotNull
    public LogEntryProvider getLogEntryProvider(final Client _client) {
        return new LogEntryProviderImpl(_client);
    }

    /**
     * Returns the singleton instance of this factory.
     * @return the singleton instance of this factory.
     */
    public static LogEntryProviderFactory getInstance() {
        return INSTANCE;
    }
}
