/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging.events;

import ar.amgomez.idea.remotetail.logging.LogEntry;

import java.util.EventListener;

/**
 * Interface that gets notifications from a log entry provider.
 * @author Alejandro Gomez
 */
public interface LogProviderListener extends EventListener {

    /**
     * Method called when a new log entry is added.
     * @param _logEntry the log entry added.
     */
    void logEntryAdded(LogEntry _logEntry);

    /**
     * Method called when the log entry provider produces an error.
     * @param _message the error message.
     */
    void logProviderError(String _message);

    /**
     * Method called when the log entry provider produces an exception.
     * @param _exception the exception.
     */
    void logProviderException(Exception _exception);
}
