/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.net;

import ar.amgomez.idea.remotetail.settings.ConnectionInfo;

/**
 * A factory to create instances of <code>Client</code>.
 * @author Alejandro Gomez
 */
public class ClientFactory {

    /**
     * The singleton instance of this factory.
     */
    private static final ClientFactory INSTANCE = new ClientFactory();

    /**
     * Private constructor to prevent other instances.
     */
    private ClientFactory() {
    }

    /**
     * Returns a new instance of <code>Client</code>.
     * @param _connectionInfo the <code>ConnectionInfo</code>.
     * @return a new instance of <code>Client</code>.
     */
    public Client getClient(final ConnectionInfo _connectionInfo) {
        if (_connectionInfo.getProtocol() == Protocol.TELNET) {
            return new TelnetClient(_connectionInfo);
        } else {
            return new SSHClient(_connectionInfo);
        }
    }

    /**
     * Returns the singleton instance of this factory.
     * @return the singleton instance of this factory.
     */
    public static ClientFactory getInstance() {
        return INSTANCE;
    }
}
