/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.net;

/**
 * Representes the network connection protocol.
 * @author Alejandro Gomez
 */
public enum Protocol {

    /**
     * The SSH network protocol.
     */
    @SuppressWarnings({"MagicNumber"})
    SSH(22),
    /**
     * The Telnet network protocol.
     */
    @SuppressWarnings({"MagicNumber"})
    TELNET(23);

    /**
     * The default port for this protocol.
     */
    private int defaultPort;

    /**
     * Constructs a new <code>Protocol</code>.
     * @param _defaultPort the default port for the newly created protocol.
     */
    Protocol(final int _defaultPort) {
        defaultPort = _defaultPort;
    }

    /**
     * Returns the default port associated with this protocol.
     * @return the default port associated with this protocol.
     */
    public int getDefaultPort() {
        return defaultPort;
    }
}
