/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.net;

import org.jetbrains.annotations.NonNls;

/**
 * Represents a file.
 * @author Alejandro Gomez
 */
public interface RemoteFile extends Comparable {
    
    /**
     * Name of a file pointing to the actual directory.
     */
    @NonNls
    String THIS_POINTER = ".";
    /**
     * Name of a file pointing to the parent directory.
     */
    @NonNls
    String PARENT_POINTER = "..";

    /**
     * Returns the file name.
     * @return the file name.
     */
    @NonNls
    String getFilename();

    /**
     * Returns the absolute path of the file.
     * @return String
     */
    @NonNls
    String getAbsolutePath();

    /**
     * Checks if the file is a directory.
     * @return true if the file is a directory.
     */
    boolean isDirectory();

    /**
     * Checks if it is a file.
     * @return true if it is a file.
     */
    boolean isFile();

    /**
     * Checks if the file can be read.
     * @return true if the file can be read.
     */
    boolean canRead();

    /**
     * Sets the new value for the file readability.
     * @param _canRead the new value for the file readability.
     */
    void setCanRead(boolean _canRead);

    /**
     * Checks if the file is a pointer to the actual or the parent directory (. or ..).
     * @return true if the file is a pointer.
     */
    boolean isPointer();
}
