/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.net;

import ar.amgomez.idea.util.GenericCollectionUtils;
import ar.amgomez.idea.util.GenericTransformer;
import com.sshtools.j2ssh.sftp.SftpFile;

import java.util.List;

/**
 * A factory to create instances of <code>RemoteFile</code>.
 * @author Alejandro Gomez
 */
public class RemoteFileFactory {

    /**
     * The singleton instance of this factory.
     */
    private static final RemoteFileFactory INSTANCE = new RemoteFileFactory();

    /**
     * Private constructor to prevent other instances.
     */
    private RemoteFileFactory() {
    }

    /**
     * Returns a new instance of <code>Client</code>.
     * @param _file the <code>SftpFile</code>.
     * @return a new instance of <code>RemoteFile</code> encapsulating the <code>SftpFile</code>.
     */
    public RemoteFile getRemoteFile(final SftpFile _file) {
        return new SSHRemoteFile(_file);
    }

    /**
     * Returns a <code>List</code> of <code>RemoteFile</code>.
     * @param _files the <code>List</code> of <code>SftpFile</code>.
     * @return a list of <code>RemoteFile</code> encapsulating the <code>SftpFile</code>.
     */
    public List<RemoteFile> getRemoteFiles(final List<SftpFile> _files) {
        return GenericCollectionUtils.collect(_files, new GenericTransformer<RemoteFile, SftpFile>() {
            public RemoteFile transform(final SftpFile _object) {
                return getRemoteFile(_object);
            }
        });
    }

    /**
     * Returns the singleton instance of this factory.
     * @return the singleton instance of this factory.
     */
    public static RemoteFileFactory getInstance() {
        return INSTANCE;
    }
}
