/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.ui;

import ar.amgomez.idea.remotetail.RemoteTailBundle;
import ar.amgomez.idea.remotetail.RemoteTailHelper;
import ar.amgomez.idea.remotetail.settings.ConnectionInfo;
import ar.amgomez.idea.remotetail.settings.Settings;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.DialogWrapper;

import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * The dialog for configuring and selecting the connections.
 * @author Alejandro Gomez
 */
public class ConnectDialog extends DialogWrapper {

    /**
     * The form for configuring and selecting the connections.
     */
    private ConnectionForm connectionForm;
    /**
     * The configuration.
     */
    private Settings settings;

    /**
     * Constructs a new <code>ConnectDialog</code>.
     * @param _project the open <code>Project</code>.
     * @param _settings the configuration.
     */
    public ConnectDialog(final Project _project, final Settings _settings) {
        super(_project, true);
        settings = _settings;
        connectionForm = new ConnectionForm(settings);
        connectionForm.addSettingsChangeListener(new ListSelectionListener() {
            public void valueChanged(final ListSelectionEvent _event) {
                final ConnectionInfo connectionInfo = settings.getConnectionInfo();
                setOKActionEnabled(connectionInfo != null && connectionInfo.isValid());
            }
        });
        setTitle(RemoteTailBundle.message("remotetail.connection.dialog.title"));
        setOKActionEnabled(settings.getConnectionInfo().isValid());
        init();
    }

    /**
     * This method is invoked by the "OK" action.
     * Applies the configuration changes.
     */
    @Override
    protected void doOKAction() {
        super.doOKAction();
        if (isOKActionEnabled()) {
            RemoteTailHelper.getSettings().apply();
        }
    }

    /**
     * This method is invoked by the "Cancel" action.
     * Resets the configuration to its previous state.
     */
    @Override
    public void doCancelAction() {
        super.doCancelAction();
        RemoteTailHelper.getSettings().reset();
    }

    /**
     * Returns the center panel.
     * @return the center panel.
     */
    @Override
    protected JComponent createCenterPanel() {
        return connectionForm.getPanel();
    }

    /**
     * Dispose all the resources allocated.
     */
    @Override
    protected void dispose() {
        connectionForm.dispose();
        super.dispose();
    }
}
