/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.ui;

import ar.amgomez.idea.remotetail.LogConsoleModel;
import ar.amgomez.idea.remotetail.events.LogHeaderListener;

import java.awt.Component;

/**
 * Represents the component for viewing the log file.
 * @author Alejandro Gomez
 */
public interface LogConsoleView {

    /**
     * Returns the model associated with this console.
     * @return the model associated with this console.
     */
    LogConsoleModel getModel();

    /**
     * Returns the title.
     * @return the title.
     */
    String getTitle();

    /**
     * Returns the UI component.
     * @return the UI component.
     */
    Component getComponent();

    /**
     * Disposes this component.
     */
    void dispose();

    /**
     * Registers a new <code>LogHeaderListener</code>.
     * @param _listener the <code>LogHeaderListener</code> to register.
     */
    void addLogHeaderListener(LogHeaderListener _listener);

    /**
     * Unregisters a <code>LogHeaderListener</code>.
     * @param _listener the <code>LogHeaderListener</code> to unregister.
     */
    void removeLogHeaderListener(LogHeaderListener _listener);
}
