/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.ui;

import ar.amgomez.idea.remotetail.RemoteTailBundle;
import ar.amgomez.idea.remotetail.net.RemoteFile;
import com.intellij.openapi.help.HelpManager;
import com.intellij.openapi.ui.DialogWrapper;
import org.jetbrains.annotations.Nullable;

import javax.swing.JComponent;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import java.awt.Component;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

/**
 * The UI dialog for choosing a file from a remote file system.
 * @author Alejandro Gomez
 */
public class RemoteFileChooserDialog extends DialogWrapper {

    /**
     * The <code>RemoteFileChooser</code> associated with this component.
     */
    private RemoteFileChooser remoteFileChooser;

    /**
     * Constructs a new <code>RemoteFileChooserDialog</code>.
     * @param _remoteFileChooser the <code>RemoteFileChooser</code> associated with the newly created component.
     * @param _parent parent component which is used to canculate heavy weight window ancestor.
     *               <code>_parent</code> cannot be <code>null</code> and must be showing.
     */
    public RemoteFileChooserDialog(final RemoteFileChooser _remoteFileChooser, final Component _parent) {
        super(_parent, false);
        remoteFileChooser = _remoteFileChooser;
        remoteFileChooser.addKeyListener(new KeyAdapter() {
            @Override
            public void keyReleased(final KeyEvent _event) {
                if (_event.getKeyCode() == KeyEvent.VK_ENTER && isOKActionEnabled()) {
                    doOKAction();
                }
            }
        });
        remoteFileChooser.addTreeSelectionListener(new TreeSelectionListener() {
            public void valueChanged(final TreeSelectionEvent _event) {
                final RemoteFile selectedFile = remoteFileChooser.getSelectedFile();
                setOKActionEnabled(selectedFile != null && selectedFile.isFile() && selectedFile.canRead());
            }
        });
        setOKActionEnabled(false);
        setTitle(RemoteTailBundle.message("remotetail.connection.selectFile"));
        init();
    }

    /**
     * Returns the associated <code>RemoteFileChooser</code> panel.
     * @return the center panel.
     */
    @Override
    @Nullable
    protected JComponent createCenterPanel() {
        return remoteFileChooser.getPanel();
    }

    /**
     * Shows the help for this dialog.
     */
    @Override
    protected void doHelpAction() {
        HelpManager.getInstance().invokeHelp("remotetail");
    }
}
