/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.ui;

import ar.amgomez.idea.remotetail.RemoteTailBundle;
import ar.amgomez.idea.remotetail.RemoteTailHelper;
import com.intellij.openapi.help.HelpManager;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.DialogWrapper;

import javax.swing.JComponent;

/**
 * The dialog for configuring this plugin.
 * @author Alejandro Gomez
 */
public class SettingsDialog extends DialogWrapper {

    /**
     * Constructs a new <code>SettingsDialog</code>.
     * @param _project the open <code>Project</code>.
     */
    public SettingsDialog(final Project _project) {
        super(_project, true);
        setTitle(RemoteTailBundle.message("remotetail.settings.dialog.title"));
        init();
    }

    /**
     * This method is invoked by the "OK" action.
     * Applies the configuration changes.
     */
    @Override
    protected void doOKAction() {
        super.doOKAction();
        RemoteTailHelper.getSettings().apply();
    }

    /**
     * This method is invoked by the "Cancel" action.
     * Resets the configuration to its previous state.
     */
    @Override
    public void doCancelAction() {
        super.doCancelAction();
        RemoteTailHelper.getSettings().reset();
    }

    /**
     * Shows the help for this dialog.
     */
    @Override
    protected void doHelpAction() {
        HelpManager.getInstance().invokeHelp("remotetail");
    }

    /**
     * Returns the center panel.
     * @return the center panel.
     */
    @Override
    protected JComponent createCenterPanel() {
        return RemoteTailHelper.getRemoteTailSettings().createComponent();
    }
}
