/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.ui;

import ar.amgomez.idea.remotetail.settings.Settings;
import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.fileChooser.FileChooserDescriptor;
import com.intellij.openapi.fileChooser.FileChooserDialog;
import com.intellij.openapi.fileChooser.FileChooserFactory;
import com.intellij.openapi.ui.TextFieldWithBrowseButton;
import com.intellij.openapi.vfs.VfsUtil;
import com.intellij.openapi.vfs.VirtualFile;

import javax.swing.JPanel;
import javax.swing.JTextField;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.io.File;
import java.net.MalformedURLException;

public class SettingsForm {

    private static final Logger LOGGER = Logger.getInstance(SettingsForm.class.getName());

    private Settings settings;
    private JPanel panel;
    private JTextField txtBufferSize;
    private TextFieldWithBrowseButton txtAudioClip;

    public SettingsForm(final Settings _settings) {
        settings = _settings;
        if (_settings.getBufferSize() > 0) {
            txtBufferSize.setText(String.valueOf(_settings.getBufferSize()));
        }
        txtBufferSize.setInputVerifier(new NumericInputVerifier());
        txtBufferSize.addKeyListener(new KeyAdapter() {
            @Override
            public void keyReleased(final KeyEvent _event) {
                fireSettingsUpdate();
            }
        });
        txtAudioClip.setText(_settings.getAudioClipPath());
        txtAudioClip.addActionListener(new ActionListener() {
            public void actionPerformed(final ActionEvent _event) {
                final FileChooserDialog fileChooser = FileChooserFactory.getInstance().createFileChooser(new FileChooserDescriptor(true, false, false, false, false, false), panel);
                VirtualFile folder = null;
                try {
                    folder = VfsUtil.findFileByURL(new File(settings.getAudioClipPath()).toURL());
                } catch (Exception ex) {
                    try {
                        folder = VfsUtil.findFileByURL(new File(System.getProperty("user.home")).toURL());
                    } catch (MalformedURLException innerEx) {
                        LOGGER.error(ex);
                    }
                }
                final VirtualFile[] files = fileChooser.choose(folder, null);
                if (files.length > 0) {
                    txtAudioClip.setText(files[0].getPath());
                    fireSettingsUpdate();
                }
            }
        });
    }

    public JPanel getPanel() {
        return panel;
    }

    private void fireSettingsUpdate() {
        int  bufferSize;
        try {
            bufferSize = Integer.parseInt(txtBufferSize.getText());
        } catch (NumberFormatException ex) {
            bufferSize = -1;
        }
        settings.update(bufferSize, txtAudioClip.getText());
    }
}
