/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.util;

import com.intellij.openapi.diagnostic.Logger;

import java.io.IOException;
import java.io.Reader;

/**
 * Input/output utility methods.
 * @author Alejandro Gomez
 */
public class IOUtils {

    /**
     * Field LOGGER.
     * To inform application errors using IDEA's logging mechanism.
     */
    private static final Logger LOGGER = Logger.getInstance(IOUtils.class.getName());

    /**
     * Closes a reader informing errors via the log.
     * @param _reader the reader to close.
     */
    public static void close(final Reader _reader) {
        if (_reader != null) {
            try {
                _reader.close();
            } catch (IOException ex) {
                LOGGER.error(ex);
            }
        }
    }
}
