/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.util;

import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

/**
 * Utility methods for working with <code>String</code>.
 * @author Alejandro Gomez
 */
public class StringUtils {

    /**
     * Returns an empty <code>String</code> or the original <code>String</code> if it is null or not.
     * In IDEA 6 was introduced <code>StringUtil.notNullize</code>.
     * @param _source the <code>String</code> to check for nullity.
     * @return an empty <code>String</code> if the argument is null, the original <code>String</code> otherwise.
     * @see StringUtil#notNullize(String)
     */
    @NotNull
    public static String emptyIfNull(final String _source) {
        return _source == null ? "" : _source;
    }

    /**
     * Checks two <code>String</code> for equality.
     * Both <code>String</code> can be null.
     * @param _string1 the first <code>String</code>.
     * @param _string2 the seconde <code>String</code>.
     * @return true if both <code>String</code> are equal.
     */
    public static boolean equals(@NonNls final String _string1, @NonNls final String _string2) {
        return _string1 == null && _string2 == null || _string1 != null && _string1.equals(_string2);
    }
}
