/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import ar.amgomez.idea.remotetail.net.Protocol;
import ar.amgomez.idea.remotetail.settings.ConnectionInfo;
import junit.framework.TestCase;
import org.jetbrains.annotations.NonNls;

import java.io.IOException;
import java.util.Properties;

/**
 * Class BaseRemoteTailTest.
 * @author Alejandro Gomez
 */
public class BaseRemoteTailTest extends TestCase {

    /**
     * Field TEST_PROPERTIES_PATH.
     */
    @NonNls
    private static final String TEST_PROPERTIES_PATH = "/ar/amgomez/idea/remotetail/test.properties";

    /**
     * Field properties.
     */
    private Properties properties = new Properties();

    /**
     * Class BaseRemoteTailTest Constructor.
     */
    protected BaseRemoteTailTest() {
        try {
            properties.load(getClass().getResourceAsStream(TEST_PROPERTIES_PATH));
        } catch (IOException ex) {
            throw new ExceptionInInitializerError(ex);
        }
    }

    /**
     * Method getProperty.
     * @param _key
     * @return String
     */
    protected String getProperty(@NonNls final String _key) {
        return properties.getProperty(_key);
    }

    /**
     * Method getIntProperty.
     * @param _key
     * @return int
     */
    protected int getIntProperty(@NonNls final String _key) {
        return Integer.parseInt(properties.getProperty(_key));
    }

    /**
     * returns the value for logContent.
     * @return String
     */
    protected String getLogContent() {
        return getProperty("logContent");
    }

    /**
     * returns the value for password.
     * @return String
     */
    protected String getPassword() {
        return getProperty("ssh.password");
    }

    /**
     * returns the value for username.
     * @return String
     */
    protected String getUsername() {
        return getProperty("ssh.user");
    }

    /**
     * returns the value for port.
     * @return int
     */
    protected int getPort() {
        return getIntProperty("ssh.port");
    }

    /**
     * returns the value for host.
     * @return String
     */
    protected String getHost() {
        return getProperty("ssh.host");
    }

    /**
     * returns the value for filePath.
     * @return String
     */
    protected String getFilePath() {
        return getProperty("ssh.file");
    }

    /**
     * returns the value for connectionInfo.
     * @return ConnectionInfo
     */
    protected ConnectionInfo getSSHConnectionInfo() {
        final ConnectionInfo connectionInfo = new ConnectionInfo();
        connectionInfo.setHost(getHost());
        connectionInfo.setPort(getPort());
        connectionInfo.setUsername(getUsername());
        connectionInfo.setPassword(getPassword());
        connectionInfo.setFilePath(getFilePath());
        return connectionInfo;
    }

    /**
     * returns the value for connectionInfo.
     * @return ConnectionInfo
     */
    protected ConnectionInfo getTelnetConnectionInfo() {
        final ConnectionInfo connectionInfo = new ConnectionInfo();
        connectionInfo.setHost(getProperty("telnet.host"));
        connectionInfo.setPort(getIntProperty("telnet.port"));
        connectionInfo.setUsername(getProperty("telnet.user"));
        connectionInfo.setPassword(getProperty("telnet.password"));
        connectionInfo.setFilePath(getProperty("telnet.file"));
        connectionInfo.setProtocol(Protocol.TELNET);
        return connectionInfo;
    }
}
