/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail;

import ar.amgomez.idea.remotetail.logging.LogCategory;
import ar.amgomez.idea.remotetail.logging.LogEntry;
import ar.amgomez.idea.remotetail.logging.LogEntryFactory;
import ar.amgomez.idea.remotetail.logging.LogLevel;

/**
 * Class LogConsoleFilterTest.
 * @author Alejandro Gomez
 */
public class LogConsoleFilterTest extends BaseRemoteTailTest {

    /**
     * Field unknownEntry.
     */
    private LogEntry unknownEntry;
    /**
     * Field infoEntry.
     */
    private LogEntry infoEntry;
    /**
     * Field debugEntry.
     */
    private LogEntry debugEntry;
    /**
     * Field warningEntry.
     */
    private LogEntry warningEntry;
    /**
     * Field errorEntry.
     */
    private LogEntry errorEntry;
    /**
     * Field severeEntry.
     */
    private LogEntry severeEntry;
    /**
     * Field fatalEntry.
     */
    private LogEntry fatalEntry;

    /**
     * Method setUp.
     * @throws Exception
     * @see junit.framework.TestCase#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
        final LogEntryFactory logEntryFactory = LogEntryFactory.getInstance();
        unknownEntry = logEntryFactory.getLogEntry(getProperty("unknownText"), LogCategory.UNKNOWN);
        infoEntry = logEntryFactory.getLogEntry(getProperty("infoText"), LogCategory.UNKNOWN);
        debugEntry = logEntryFactory.getLogEntry(getProperty("debugText"), LogCategory.UNKNOWN);
        warningEntry = logEntryFactory.getLogEntry(getProperty("warningText"), LogCategory.UNKNOWN);
        errorEntry = logEntryFactory.getLogEntry(getProperty("errorText"), LogCategory.UNKNOWN);
        severeEntry = logEntryFactory.getLogEntry(getProperty("severeText"), LogCategory.UNKNOWN);
        fatalEntry = logEntryFactory.getLogEntry(getProperty("fatalText"), LogCategory.UNKNOWN);
    }

    /**
     * Method testEmptyFilter.
     */
    public void testEmptyFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertTrue(filter.isUnfiltered(infoEntry));
        assertTrue(filter.isUnfiltered(debugEntry));
        assertTrue(filter.isUnfiltered(warningEntry));
        assertTrue(filter.isUnfiltered(errorEntry));
        assertTrue(filter.isUnfiltered(severeEntry));
        assertTrue(filter.isUnfiltered(fatalEntry));
    }

    /**
     * Method testInfoFilter.
     */
    public void testInfoFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        filter.addLevel(LogLevel.INFO);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertTrue(!filter.isUnfiltered(infoEntry));
        assertTrue(!filter.isUnfiltered(debugEntry));
        assertTrue(filter.isUnfiltered(warningEntry));
        assertTrue(filter.isUnfiltered(errorEntry));
        assertTrue(filter.isUnfiltered(severeEntry));
        assertTrue(filter.isUnfiltered(fatalEntry));
    }

    /**
     * Method testWarningFilter.
     */
    public void testWarningFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        filter.addLevel(LogLevel.WARNING);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertTrue(filter.isUnfiltered(infoEntry));
        assertTrue(filter.isUnfiltered(debugEntry));
        assertTrue(!filter.isUnfiltered(warningEntry));
        assertTrue(filter.isUnfiltered(errorEntry));
        assertTrue(filter.isUnfiltered(severeEntry));
        assertTrue(filter.isUnfiltered(fatalEntry));
    }

    /**
     * Method testErrorFilter.
     */
    public void testErrorFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        filter.addLevel(LogLevel.ERROR);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertTrue(filter.isUnfiltered(infoEntry));
        assertTrue(filter.isUnfiltered(debugEntry));
        assertTrue(filter.isUnfiltered(warningEntry));
        assertFalse(filter.isUnfiltered(errorEntry));
        assertFalse(filter.isUnfiltered(severeEntry));
        assertFalse(filter.isUnfiltered(fatalEntry));
    }

    /**
     * Method testFullFilter.
     */
    public void testFullFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        filter.addLevel(LogLevel.INFO);
        filter.addLevel(LogLevel.WARNING);
        filter.addLevel(LogLevel.ERROR);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertFalse(filter.isUnfiltered(infoEntry));
        assertFalse(filter.isUnfiltered(debugEntry));
        assertFalse(filter.isUnfiltered(warningEntry));
        assertFalse(filter.isUnfiltered(errorEntry));
        assertFalse(filter.isUnfiltered(severeEntry));
        assertFalse(filter.isUnfiltered(fatalEntry));
    }

    /**
     * Method testRemoveFilter.
     */
    public void testRemoveFilter() {
        final LogConsoleFilter filter = new LogConsoleFilter();
        filter.addLevel(LogLevel.INFO);
        filter.addLevel(LogLevel.WARNING);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertFalse(filter.isUnfiltered(infoEntry));
        assertFalse(filter.isUnfiltered(debugEntry));
        assertFalse(filter.isUnfiltered(warningEntry));
        assertTrue(filter.isUnfiltered(errorEntry));
        assertTrue(filter.isUnfiltered(severeEntry));
        assertTrue(filter.isUnfiltered(fatalEntry));
        filter.removeLevel(LogLevel.INFO);
        assertTrue(filter.isUnfiltered(unknownEntry));
        assertTrue(filter.isUnfiltered(infoEntry));
        assertTrue(filter.isUnfiltered(debugEntry));
        assertFalse(filter.isUnfiltered(warningEntry));
        assertTrue(filter.isUnfiltered(errorEntry));
        assertTrue(filter.isUnfiltered(severeEntry));
        assertTrue(filter.isUnfiltered(fatalEntry));
    }
}
