/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.BaseRemoteTailTest;
import ar.amgomez.idea.remotetail.logging.events.LogProviderListener;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.OutputStream;

/**
 * Class AbstractLogEntryProviderTest.
 * @author Alejandro Gomez
 */
public class AbstractLogEntryProviderTest extends BaseRemoteTailTest {

    /**
     * Field provider.
     */
    private LogEntryProviderImpl provider;

    /**
     * Method setUp.
     * @throws Exception
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
        provider = new LogEntryProviderImpl(null) {
            public boolean connect() {
                return false;
            }

            @NotNull
            OutputStream getOutputStream() throws IOException {
                return null;
            }

            @NotNull
            BufferedReader getInputReader() throws IOException {
                return null;
            }

            @Nullable
            BufferedReader getErrorReader() throws IOException {
                return null;
            }

            public void disconnect() {
            }
        };
    }

    /**
     * Method testAddLogEntryListener.
     */
    public void testAddLogEntryListener() {
        final boolean[] done = {false};
        final String text = getProperty("infoText");
        provider.addLogProviderListener(new LogProviderListener() {
            public void logEntryAdded(final LogEntry _logEntry) {
                assertEquals(LogCategory.INFO, _logEntry.getCategory());
                assertEquals(text, _logEntry.getText());
                done[0] = true;
            }

            public void logProviderError(final String _line) {
                fail("no error was generated");
            }

            public void logProviderException(final Exception _exception) {
                fail("Unexpected exception: " + _exception);
            }
        });
        provider.fireLogEntryAdded(text);
        assertTrue(done[0]);
    }

    /**
     * Method testRemoveLogEntryListener.
     */
    public void testRemoveLogEntryListener() {

    }
}
