/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.BaseRemoteTailTest;
import ar.amgomez.idea.remotetail.settings.ConnectionInfo;
import org.jetbrains.annotations.NonNls;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;

/**
 * Class BaseLogEntryProviderTest.
 * @author Alejandro Gomez
 */
public class BaseLogEntryProviderTest extends BaseRemoteTailTest {

    /**
     * Field TEMP_LOG_PREFIX.
     */
    @NonNls
    private static final String TEMP_LOG_PREFIX = "log";
    /**
     * Field TEMP_LOG_SUFFIX.
     */
    @NonNls
    private static final String TEMP_LOG_SUFFIX = ".tmp";

    /**
     * Field logFile.
     */
    private File logFile;

    /**
     * Class BaseLogEntryProviderTest Constructor.
     */
    public BaseLogEntryProviderTest() {
        try {
            logFile = File.createTempFile(TEMP_LOG_PREFIX, TEMP_LOG_SUFFIX);
        } catch (IOException ex) {
            throw new ExceptionInInitializerError(ex);
        }
    }

    /**
     * returns the value for logFile.
     * @return File
     */
    protected File getLogFile() {
        return logFile;
    }

    /**
     * Method writeLogFile.
     * @throws java.io.IOException
     */
    protected void writeLogFile() throws IOException {
        writeLogFile(getLogContent());
    }

    /**
     * Method writeLogFile.
     * @param _content
     * @throws java.io.IOException
     */
    protected void writeLogFile(final String _content) throws IOException {
        Writer writer = null;
        try {
            writer = new FileWriter(logFile);
            writer.write(_content);
        } finally {
            if (writer != null) {
                writer.close();
            }
        }
    }

    /**
     * Method isEOF.
     * @param _text
     * @return boolean
     */
    protected boolean isEOF(@NonNls final String _text) {
        return getProperty("eofMark").equals(_text);
    }

    /**
     * returns the value for connectionInfo.
     * @return ConnectionInfo
     */
    @Override
    protected ConnectionInfo getSSHConnectionInfo() {
        final ConnectionInfo connectionInfo = super.getSSHConnectionInfo();
        connectionInfo.setFilePath(logFile.getPath());
        return connectionInfo;
    }
}
