/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import org.jetbrains.annotations.NonNls;

/**
 * Class LogEntryFactoryTest.
 * @author Alejandro Gomez
 */
public class LogEntryFactoryTest extends TestCase {

    /**
     * Method testGetInstance.
     */
    public void testGetInstance() {
        final LogEntryFactory factory = LogEntryFactory.getInstance();
        assertNotNull(factory);
    }

    /**
     * Method testGetInfoLogEntry.
     */
    public void testGetInfoLogEntry() {
        getLogEntry("qwerty INFO qwerty", LogCategory.INFO);
    }

    /**
     * Method testGetDebugLogEntry.
     */
    public void testGetDebugLogEntry() {
        getLogEntry("qwerty DEBUG qwerty", LogCategory.DEBUG);
    }

    /**
     * Method testGetWarningLogEntry.
     */
    public void testGetWarningLogEntry() {
        getLogEntry("qwerty WARNING qwerty", LogCategory.WARNING);
    }

    /**
     * Method testGetErrorLogEntry.
     */
    public void testGetErrorLogEntry() {
        getLogEntry("qwerty ERROR qwerty", LogCategory.ERROR);
    }

    /**
     * Method testGetFatalLogEntry.
     */
    public void testGetFatalLogEntry() {
        getLogEntry("qwerty FATAL qwerty", LogCategory.FATAL);
    }

    /**
     * Method testGetSevereLogEntry.
     */
    public void testGetSevereLogEntry() {
        getLogEntry("qwerty SEVERE qwerty", LogCategory.SEVERE);
    }

    /**
     * Method testGetUnknownLogEntry.
     */
    public void testGetUnknownLogEntry() {
        @NonNls final String text = "qwerty qwerty";
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(text, LogCategory.INFO);
        assertNotNull(logEntry);
        assertEquals(LogCategory.INFO, logEntry.getCategory());
        assertEquals(text, logEntry.getText());
        assertFalse(logEntry.isHeader());
    }

    /**
     * Method getLogEntry.
     * @param _text
     * @param _category
     */
    private static void getLogEntry(@NonNls final String _text, final LogCategory _category) {
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(_text, LogCategory.UNKNOWN);
        assertNotNull(logEntry);
        assertEquals(_category, logEntry.getCategory());
        assertEquals(_text, logEntry.getText());
        assertTrue(logEntry.isHeader());
    }

    /**
     * Method testGetInfoLogCategory.
     */
    public void testGetInfoLogCategory() {
        getLogCategory("asdfgh INFO asdfgh", LogCategory.INFO);
    }

    /**
     * Method testGetDebugLogCategory.
     */
    public void testGetDebugLogCategory() {
        getLogCategory("asdfgh DEBUG asdfgh", LogCategory.DEBUG);
    }

    /**
     * Method testGetWarningLogCategory.
     */
    public void testGetWarningLogCategory() {
        getLogCategory("asdfgh WARNING asdfgh", LogCategory.WARNING);
    }

    /**
     * Method testGetErrorLogCategory.
     */
    public void testGetErrorLogCategory() {
        getLogCategory("asdfgh ERROR asdfgh", LogCategory.ERROR);
    }

    /**
     * Method testGetFatalLogCategory.
     */
    public void testGetFatalLogCategory() {
        getLogCategory("asdfgh FATAL asdfgh", LogCategory.FATAL);
    }

    /**
     * Method testGetSevereLogCategory.
     */
    public void testGetSevereLogCategory() {
        getLogCategory("asdfgh SEVERE asdfgh", LogCategory.SEVERE);
    }

    /**
     * Method testGetUnknownLogCategory.
     */
    public void testGetUnknownLogCategory() {
        getLogCategory("asdfgh asdfgh", LogCategory.INFO);
    }

    /**
     * Method getLogCategory.
     * @param _text
     * @param _expectedCategory
     */
    private static void getLogCategory(@NonNls final String _text, final LogCategory _expectedCategory) {
        final LogCategory category = LogEntryFactory.getInstance().getLogCategory(_text, _expectedCategory);
        assertNotNull(category);
        assertEquals(_expectedCategory, category);
    }

    /**
     * Method suite.
     * @return Test
     */
    public static Test suite() {
        return new TestSuite(LogEntryFactoryTest.class);
    }
}
