/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.BaseRemoteTailTest;

/**
 * Class LogEntryImplTest.
 * @author Alejandro Gomez
 */
public class LogEntryImplTest extends BaseRemoteTailTest {

    /**
     * Method testGetText.
     */
    public void testGetText() {
        final String infoText = getProperty("infoText");
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(infoText, LogCategory.UNKNOWN);
        assertNotNull(logEntry);
        assertEquals(infoText, logEntry.getText());
        assertTrue(logEntry.isHeader());
    }

    /**
     * Method testGetCategory.
     */
    public void testGetCategory() {
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(getProperty("unknownText"), LogCategory.WARNING);
        assertNotNull(logEntry);
        assertEquals(LogCategory.WARNING, logEntry.getCategory());
        assertFalse(logEntry.isHeader());
    }

    /**
     * Method testGetCategoryForHeader.
     */
    public void testGetCategoryForHeader() {
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(getProperty("errorText"), LogCategory.UNKNOWN);
        assertNotNull(logEntry);
        assertEquals(LogCategory.ERROR, logEntry.getCategory());
        assertTrue(logEntry.isHeader());
    }

    /**
     * Method testIsHeader.
     */
    public void testIsHeader() {
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(getProperty("warningText"), LogCategory.UNKNOWN);
        assertNotNull(logEntry);
        assertEquals(LogCategory.WARNING, logEntry.getCategory());
        assertTrue(logEntry.isHeader());
        assertFalse(logEntry.isHeader(LogLevel.INFO));
        assertTrue(logEntry.isHeader(LogLevel.WARNING));
        assertFalse(logEntry.isHeader(LogLevel.ERROR));
    }

    /**
     * Method testIsHeaderNonStrict.
     */
    public void testIsHeaderNonStrict() {
        final LogEntry logEntry = LogEntryFactory.getInstance().getLogEntry(getProperty("warningText"), LogCategory.UNKNOWN);
        assertNotNull(logEntry);
        assertEquals(LogCategory.WARNING, logEntry.getCategory());
        assertTrue(logEntry.isHeader());
        assertTrue(logEntry.isHeaderNonStrict(LogLevel.INFO));
        assertTrue(logEntry.isHeaderNonStrict(LogLevel.WARNING));
        assertFalse(logEntry.isHeaderNonStrict(LogLevel.ERROR));
    }
}
