/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.BaseRemoteTailTest;
import ar.amgomez.idea.remotetail.net.ClientFactory;
import ar.amgomez.idea.remotetail.net.Protocol;
import ar.amgomez.idea.remotetail.settings.ConnectionInfo;
import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Class LogEntryProviderFactoryTest.
 * @author Alejandro Gomez
 */
public class LogEntryProviderFactoryTest extends BaseRemoteTailTest {

    /**
     * Method testGetSSHLogEntryProvider.
     */
    public void testGetSSHLogEntryProvider() {
        final ConnectionInfo connectionInfo = getSSHConnectionInfo();
        connectionInfo.setPort(Protocol.SSH.getDefaultPort());
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNotNull(provider);
        assertEquals(getHost(), provider.getHost());
        assertEquals(Protocol.SSH.getDefaultPort(), provider.getPort());
        assertEquals(getUsername(), provider.getUsername());
        assertEquals(getFilePath(), provider.getFilePath());
    }

    /**
     * Method testGetTelnetLogEntryProvider.
     */
    public void testGetTelnetLogEntryProvider() {
        final ConnectionInfo connectionInfo = getSSHConnectionInfo();
        connectionInfo.setPort(Protocol.TELNET.getDefaultPort());
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNotNull(provider);
        assertEquals(getHost(), provider.getHost());
        assertEquals(Protocol.TELNET.getDefaultPort(), provider.getPort());
        assertEquals(getUsername(), provider.getUsername());
        assertEquals(getFilePath(), provider.getFilePath());
    }

    /**
     * Method testGetInstance.
     */
    public void testGetInstance() {
        final LogEntryProviderFactory factory = LogEntryProviderFactory.getInstance();
        assertNotNull(factory);
    }

    /**
     * Method suite.
     * @return Test
     */
    public static Test suite() {
        return new TestSuite(LogEntryProviderFactoryTest.class);
    }
}
