/*
 *    Copyright 2006 Alejandro Gomez
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *
 */
package ar.amgomez.idea.remotetail.logging;

import ar.amgomez.idea.remotetail.logging.events.LogProviderListener;
import ar.amgomez.idea.remotetail.net.ClientFactory;
import ar.amgomez.idea.remotetail.settings.ConnectionInfo;

import java.io.IOException;

/**
 * Class TelnetLogEntryProviderTest.
 * @author Alejandro Gomez
 */
public class TelnetLogEntryProviderTest extends BaseLogEntryProviderTest {

    /**
     * Method testHappyPath.
     * @throws java.io.IOException
     */
    public void testHappyPath() throws IOException {
        final ConnectionInfo connectionInfo = getTelnetConnectionInfo();
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNotNull(provider);
        provider.connect();
        final boolean[] done = {false};
        provider.addLogProviderListener(new LogProviderListener() {
            public void logEntryAdded(final LogEntry _logEntry) {
                final String text = _logEntry.getText();
                assertNotNull(text);
                done[0] = isEOF(text);
            }

            public void logProviderError(final String _line) {
                fail("Unexpected error: " + _line);
            }

            public void logProviderException(final Exception _exception) {
                fail("Unexpected exception: " + _exception);
            }
        });
        writeLogFile();
        while (!done[0]);
        provider.disconnect();
    }

    public void testHappyPath2() throws IOException {
        final ConnectionInfo connectionInfo = getTelnetConnectionInfo();
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNotNull(provider);
        provider.connect();
        final boolean[] done = {false};
        provider.addLogProviderListener(new LogProviderListener() {
            private int count;
            public void logEntryAdded(final LogEntry _logEntry) {
                final String text = _logEntry.getText();
                assertNotNull(text);
                System.out.println(text);
                done[0] = ++count >= 10;
            }

            public void logProviderError(final String _line) {
                fail("Unexpected error: " + _line);
            }

            public void logProviderException(final Exception _exception) {
                fail("Unexpected exception: " + _exception);
            }
        });
        while (!done[0]);
        provider.disconnect();
    }

    /**
     * Method testFileNotFound.
     * @throws java.io.IOException
     */
    public void testFileNotFound() throws IOException {
        final ConnectionInfo connectionInfo = getSSHConnectionInfo();
        connectionInfo.setFilePath("/qwerty");
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNotNull(provider);
        provider.connect();
        final boolean[] done = {false};
        provider.addLogProviderListener(new LogProviderListener() {
            public void logEntryAdded(final LogEntry _logEntry) {
                fail("Unexpected entry: " + _logEntry);
            }

            public void logProviderError(final String _line) {
                assertNotNull(_line);
                done[0] = true;
            }

            public void logProviderException(final Exception _exception) {
                fail("Unexpected exception: " + _exception);
            }
        });
        while (!done[0]);
    }

    /**
     * Method testConnectionException.
     * @throws java.io.IOException
     */
    public void testConnectionException() throws IOException {
        final ConnectionInfo connectionInfo = getSSHConnectionInfo();
        connectionInfo.setPort(65535);
        connectionInfo.setFilePath("/qwerty");
        final LogEntryProvider provider = LogEntryProviderFactory.getInstance().getLogEntryProvider(ClientFactory.getInstance().getClient(connectionInfo));
        assertNull(provider);
    }
}
